@@ -2,7 +2,6 @@
 Tests for django-analytical.
 """
 
-from analytical.tests.test_geckoboard import *
 from analytical.tests.test_tag_analytical import *
 from analytical.tests.test_tag_chartbeat import *
 from analytical.tests.test_tag_clicky import *
@@ -12,6 +11,8 @@ from analytical.tests.test_tag_hubspot import *
 from analytical.tests.test_tag_kiss_insights import *
 from analytical.tests.test_tag_kiss_metrics import *
 from analytical.tests.test_tag_mixpanel import *
+from analytical.tests.test_tag_olark import *
 from analytical.tests.test_tag_optimizely import *
 from analytical.tests.test_tag_performable import *
+from analytical.tests.test_tag_reinvigorate import *
 from analytical.tests.test_utils import *
